==> nextcloud-app-bookmarks-1%3A13.1.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/uk.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Закладки",
    "No file provided for import" : "Відсутній файл для імпорту",
    "Unsupported file type for import" : "Цей тип файлу не підтримується",
    "Details" : "Деталі",
    "Rename" : "Перейменувати",
    "Copy link" : "Копіювати посилання",
    "Move" : "Перемістити",
    "Delete" : "Вилучити",
    "This content is being downloaded for offline use. Please check back later." : "Вміст завантажується для використання в режимі офлайн. Будь ласка, перевірте пізніше.",
    "Delete selection" : "Прибрати виділення",
    "Select all" : "Вибрати все",
    "Go back" : "Повернутися назад",
    "Share folder" : "Спільний доступ до каталогу",
    "Select one or more tags" : "Виберіть одну або кілька міток",
    "New" : "Створити",
    "New folder" : "Новий каталог",
    "Search" : "Пошук",
    "Sort by last modified" : "Впорядкувати за останніми змінами",
    "Sort by title" : "Сортувати за назвою",
    "Enter a link" : "Зазначте посилання",
    "Add a bookmark" : "Додати закладку",
    "Shared by {user}" : "{user} надав(-ла) доступ",
    "Rename folder" : "Перейменувати каталог",
    "Delete folder" : "Вилучити каталог",
    "Submit" : "Гаразд",
    "Cancel" : "Скасувати",
    "Recent" : "Нещодавні",
    "Shared with you" : "Вам надано доступ",
    "Files" : "Робота з файлами",
    "Import" : "Імпорт",
    "Export" : "Експорт",
    "Title" : "Назва",
    "Link" : "Посилання",
    "Root folder" : "Кореневий каталог",
    "Tags" : "Мітки",
    "Notes" : "Примітки",
    "Created {time} ago" : "Створено {time} тому",
    "Owner" : "Власник",
    "Sharing" : "Поділитися",
    "Select a user or group" : "Виберіть користувача або групу",
    "Share link" : "Поділитися посиланням",
    "Resharing allowed" : "Дозволено передавати у спільний доступ іншим",
    "Editing allowed" : "Редагування дозволено",
    "Allow editing" : "Дозволити редагування",
    "Allow resharing" : "Дозволити передавати у спільний доступ іншим",
    "Link copied" : "Посилання скопійовано",
    "Privacy" : "Конфіденційність",
    "Failed to save settings" : "Неможливо зберегти налаштування",
    "Failed to load settings" : "Не вдалося завантажити налаштування",
    "This URL is already bookmarked! Overwrite?" : "Цей URL вже є в закладках! Перезаписати?",
    "Folder" : "Каталог",
    "Save" : "Зберегти",
    "Failed to load tags" : "Не вдалося завантажити мітки"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-app-bookmarks-1%3A13.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/uk.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Закладки",
    "No file provided for import" : "Відсутній файл для імпорту",
    "Unsupported file type for import" : "Цей тип файлу не підтримується",
    "Details" : "Деталі",
    "Rename" : "Перейменувати",
    "Copy link" : "Копіювати посилання",
    "Move" : "Перемістити",
    "Delete" : "Вилучити",
    "This content is being downloaded for offline use. Please check back later." : "Вміст завантажується для використання в режимі офлайн. Будь ласка, перевірте пізніше.",
    "Delete selection" : "Прибрати виділення",
    "Select all" : "Вибрати все",
    "Go back" : "Повернутися назад",
    "Share folder" : "Спільний доступ до каталогу",
    "Select one or more tags" : "Виберіть одну або кілька міток",
    "New" : "Створити",
    "New folder" : "Новий каталог",
    "Change to grid view" : "Перехід до перегляду у вигляді сітки",
    "Change to list view" : "Перейдіть до перегляду у вигляді списку",
    "Search" : "Пошук",
    "Sort by last modified" : "Впорядкувати за останніми змінами",
    "Sort by title" : "Впорядкувати за назвою",
    "Enter a link" : "Зазначте посилання",
    "Add a bookmark" : "Додати закладку",
    "Shared by {user}" : "{user} надав(-ла) доступ",
    "Rename folder" : "Перейменувати каталог",
    "Delete folder" : "Вилучити каталог",
    "Submit" : "Гаразд",
    "Cancel" : "Скасувати",
    "Recent" : "Нещодавні",
    "Shared with you" : "Вам надано доступ",
    "Files" : "Робота з файлами",
    "Import" : "Імпорт",
    "Export" : "Експорт",
    "Title" : "Назва",
    "Link" : "Посилання",
    "Root folder" : "Кореневий каталог",
    "Tags" : "Мітки",
    "Notes" : "Примітки",
    "Created {time} ago" : "Створено {time} тому",
    "Owner" : "Власник",
    "Sharing" : "Поділитися",
    "Select a user or group" : "Виберіть користувача або групу",
    "Share link" : "Поділитися посиланням",
    "Resharing allowed" : "Дозволено передавати у спільний доступ іншим",
    "Editing allowed" : "Редагування дозволено",
    "Allow editing" : "Дозволити редагування",
    "Allow resharing" : "Дозволити передавати у спільний доступ іншим",
    "Link copied" : "Посилання скопійовано",
    "Privacy" : "Конфіденційність",
    "Failed to save settings" : "Неможливо зберегти налаштування",
    "Failed to load settings" : "Не вдалося завантажити налаштування",
    "This URL is already bookmarked! Overwrite?" : "Цей URL вже є в закладках! Перезаписати?",
    "Folder" : "Каталог",
    "Save" : "Зберегти",
    "What" : "Що?",
    "Failed to load tags" : "Не вдалося завантажити мітки"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
